import React, { forwardRef, useEffect } from 'react';
import { useImperativeHandle, useRef } from 'react';
import { requireNativeComponent, UIManager, findNodeHandle, DeviceEventEmitter, Platform } from 'react-native';
const OdpViewManagerCommands = {
  start: 1,
  upload_logs: 2
};
const startOdp = (viewId, key, host) => UIManager.dispatchViewManagerCommand(viewId, OdpViewManagerCommands.start.toString(), [key, host]);
const uploadLogs = viewId => UIManager.dispatchViewManagerCommand(viewId, OdpViewManagerCommands.upload_logs.toString(), []);
const LINKING_ERROR = `The package 'react-native-library' doesn't seem to be linked. Make sure: \n\n` + Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const OdpComponent = UIManager.getViewManagerConfig('OdpViewManager') != null ? requireNativeComponent('OdpViewManager') : () => {
  throw new Error(LINKING_ERROR);
};
const OdpModule = (props, parentRef) => {
  const nodeRef = useRef(null);
  useEffect(() => {
    console.log('Initializing Event Emitter');
    const eventEmitter = DeviceEventEmitter;
    eventEmitter.addListener('onReady', event => {
      var _props$onOdpEvent$onR, _props$onOdpEvent;
      (_props$onOdpEvent$onR = (_props$onOdpEvent = props.onOdpEvent).onReady) === null || _props$onOdpEvent$onR === void 0 ? void 0 : _props$onOdpEvent$onR.call(_props$onOdpEvent, event);
    });
    eventEmitter.addListener('onKeyValidation', event => {
      var _props$onOdpEvent$onK, _props$onOdpEvent2;
      (_props$onOdpEvent$onK = (_props$onOdpEvent2 = props.onOdpEvent).onKeyValidation) === null || _props$onOdpEvent$onK === void 0 ? void 0 : _props$onOdpEvent$onK.call(_props$onOdpEvent2, event);
    });
    eventEmitter.addListener('onNavigationUpdate', event => {
      var _props$onOdpEvent$onN, _props$onOdpEvent3;
      (_props$onOdpEvent$onN = (_props$onOdpEvent3 = props.onOdpEvent).onNavigationUpdate) === null || _props$onOdpEvent$onN === void 0 ? void 0 : _props$onOdpEvent$onN.call(_props$onOdpEvent3, event);
    });
    eventEmitter.addListener('onFacilityUpdate', event => {
      var _props$onOdpEvent$onF, _props$onOdpEvent4;
      (_props$onOdpEvent$onF = (_props$onOdpEvent4 = props.onOdpEvent).onFacilityUpdate) === null || _props$onOdpEvent$onF === void 0 ? void 0 : _props$onOdpEvent$onF.call(_props$onOdpEvent4, event);
    });
    return () => {
      eventEmitter.removeAllListeners('onReady');
      eventEmitter.removeAllListeners('onKeyValidation');
      eventEmitter.removeAllListeners('onNavigationUpdate');
      eventEmitter.removeAllListeners('onFacilityUpdate');
    };
  }, []);
  useImperativeHandle(parentRef, () => {
    const nodeHandle = findNodeHandle(nodeRef.current);
    const listeners = {
      startOdp: (key, host) => {
        startOdp(nodeHandle, key, host);
      },
      uploadLogs: () => {
        uploadLogs(nodeHandle);
      }
    };
    return listeners;
  });

  // @ts-ignore
  return /*#__PURE__*/React.createElement(OdpComponent, {
    ref: nodeRef
  });
};
export default /*#__PURE__*/forwardRef(OdpModule);
//# sourceMappingURL=OdpViewModule.js.map